Learn R Programming

SensIAT (version 0.1.1)

Cond_mean_fn: Estimate Subject Predicted Mean Outcome

Description

This function is used to get a subject's predicted mean outcome under a given sensitivity parameter value alpha. It is specific to the outcome model that we used on the ARC data (which was negative binomial), and specific to the tilting function alpha*Y(t), so would need to be changed if using a different outcome model or different tilting function.

Usage

Cond_mean_fn(mu, theta, alpha)

Value

a list containing \(\frac{E[ Y exp(\alpha Y) ]}{E[ exp(\alpha Y)]}\)

and $E[ exp(\alpha Y) ]$

for Y a (truncated version of) a negative binomial having mean mu and size theta.

Arguments

mu

mean

theta

size

alpha

sensitivity