Learn R Programming

SensIAT (version 0.1.1)

SensIAT_jackknife: Estimate response with jackknife resampling

Description

Estimate response with jackknife resampling

Usage

SensIAT_jackknife(original.object, time, ...)

Value

A tibble with columns alpha, time, jackknife_mean, and jackknife_var, where jackknife_mean is the mean of the jackknife estimates and jackknife_var is the estimated variances of the response at the given time points for the specified alpha values.

Arguments

original.object

A SensIAT_within_group_model object.

time

Time points for which to estimate the response.

...

currently ignored.

Examples

Run this code
if (FALSE) {
original.object <-
fit_SensIAT_within_group_model(
    group.data = SensIAT_example_data,
    outcome_modeler = SensIAT_sim_outcome_modeler,
    alpha = c(-0.6, -0.3, 0, 0.3, 0.6),
    id.var = Subject_ID,
    outcome.var = Outcome,
    time.var = Time,
    intensity.bandwidth = 30,
    knots = c(60,60,60,60,260,460,460,460,460),
    End = 830
)
jackknife.estimates <- SensIAT_jackknife(original.object, time = c(90, 180, 270, 360, 450))
}

Run the code above in your browser using DataLab