Skip to contents

By default this returns original fitted coefficients. If sampling is requested, coefficients are sampled from an asymptotic multivariate normal distribution only when vcov() is available.

Usage

get_bootstrap_coeffs(model, sample_coefficients = FALSE, model_label = "model")

Arguments

model

A fitted model with coef() and vcov() methods.

sample_coefficients

Logical; if TRUE, sample coefficients from an asymptotic multivariate normal distribution when vcov() is available. If FALSE (default), use original fitted coefficients.

model_label

Character; label for the model used in warning messages.