Compute Conditional Means
pcori_conditional_means(model, alpha = 0, new.data = model.frame(model), ...)The new.data frame with additional columns E_Y_past, and E_exp_alphaY appended.
An object of class SensIAT::outcome-model
Sensitivity parameter
Data to compute conditional means for, defaults to the model frame for the fitted model.
passed onto methods.
Compute the conditional expectations needed for predictions in the models. Three additional values/expectations are computed:
$E \big[ Y(t) \exp \{ \alpha Y(t) \} | A(t)=1, \bar{O}(t) \big]$, returned as E_y_past, and
$E \big[ \exp \{ \alpha Y(t) \} \ | A(t)=1, \bar{O}(t) \big]$, returned as E_exp_alphaY.