Control Parameters for Fitting the within Group Model
pcori_control(
integration.method = c("quadvcpp", "quadv", "linear", "numerical", "piecewise"),
intensity.bandwidth = NULL,
resolution = 1000,
resolution.within.period = 50,
tol = .Machine$double.eps^(1/4),
...
)a list of control parameters.
Method for integration when computing the second influence term.
The bandwidth for the intensity model.
The number of points to use for numerical integration.
The number of points to use for numerical integration within a period.
The tolerance for numerical integration.
Currently ignored.