Runs an optimized implementation of the "NW" function.
pcoriaccel_NW(Xb, Y, xb, y_seq, h, kernel = "K2_Biweight")A matrix of the same size as xb by y_seq.
a vector (expected to be about 500 elements)
a vector (same size as Xb)
a vector
a vector
a scalar, the bandwidth of kernel
a string, denoting the kernel function to use, either "dnorm", "K2_Biweight", or "K4_Biweight"