Directly estimate the probability mass function of Y.
pcoriaccel_estimate_pmf(Xb, Y, xi, y_seq, h, kernel = "K2_Biweight")Numeric vector of individual linear predictors from the data
Numeric vector of individual responses from the data
value of the individuals linear predictor at the point of estimation
Numeric vector of unique values of Y.
bandwidth of the kernel
character string specifying the kernel to use, either "dnorm", "K2_Biweight", or "K4_Biweight"