Sample parametric coefficients from a fitted model using asymptotic multivariate normal distribution.
Source:R/parametric_bootstrap.R
sample_parametric_coeffs.RdSample parametric coefficients from a fitted model using asymptotic multivariate normal distribution.